Uses of Class org.openqa.selenium.server.ProxyHandler (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.ProxyHandler

Packages that use ProxyHandler
org.openqa.selenium.server | Provides the core Selenium Server classes.

Uses of ProxyHandler in org.openqa.selenium.server

Methods in org.openqa.selenium.server that return ProxyHandler
`protected ProxyHandler` | `SeleniumServer.makeProxyHandler(RemoteControlConfiguration configuration)`

Methods in org.openqa.selenium.server with parameters of type ProxyHandler
`static void` | `SeleniumServer.setCustomProxyHandler(ProxyHandler customProxyHandler)` Used for implementations that invoke SeleniumServer programmatically and require additional logic when proxying data.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.